@@ -104,7 +104,7 @@ def get_page(link):
 
 
 def parser():
-    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
+    log.debug(f"The script {__name__} starts working")
     html = f.get_html(COMPLEX_URL)
     soup = BeautifulSoup(html.text, 'html.parser')
     links = []
