@@ -165,7 +165,7 @@ def get_orenburg():
     return people
 
 def parser():
-    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
+    log.debug(f"The script {__name__} starts working")
     links = []
     people = []
     html = f.get_html(url)
