@@ -48,7 +48,7 @@ def get_content(html, cont_id, cont_work_id):
 
 
 def parser(URL, cont_id=1, cont_id_work=37):
-    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
+    log.debug(f"The script {__name__} starts working")
     html = f.get_html(URL)
     if html.status_code == 200:
         person = get_content(html,cont_id, cont_id_work)
